@@ -4,9 +4,10 @@
      $                    WORK, IWORK, INFO )
       IMPLICIT NONE
 *
-*  -- LAPACK auxiliary routine (version 3.1) --
-*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd..
-*     November 2006
+*  -- LAPACK auxiliary routine (version 3.3.0) --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
+*     November 2010
 *
 *     .. Scalar Arguments ..
       CHARACTER          RANGE
@@ -40,7 +41,7 @@
 *  Arguments
 *  =========
 *
-*  RANGE   (input) CHARACTER
+*  RANGE   (input) CHARACTER*1
 *          = 'A': ("All")   all eigenvalues will be found.
 *          = 'V': ("Value") all eigenvalues in the half-open interval
 *                           (VL, VU] will be found.
@@ -90,7 +91,7 @@
 *           An interval [LEFT,RIGHT] has converged if
 *           RIGHT-LEFT.LT.MAX( RTOL1*GAP, RTOL2*MAX(|LEFT|,|RIGHT|) )
 *
-*  SPLTOL (input) DOUBLE PRECISION
+*  SPLTOL  (input) DOUBLE PRECISION
 *          The threshold for splitting.
 *
 *  NSPLIT  (output) INTEGER
@@ -303,6 +304,10 @@
 *     Option left in the code for future multisection work.
       FORCEB = .FALSE.
 
+*     Initialize USEDQD, DQDS should be used for ALLRNG unless someone
+*     explicitly wants bisection.
+      USEDQD = (( IRANGE.EQ.ALLRNG ) .AND. (.NOT.FORCEB))
+
       IF( (IRANGE.EQ.ALLRNG) .AND. (.NOT. FORCEB) ) THEN
 *        Set interval [VL,VU] that contains all eigenvalues
          VL = GL
